新世界 (豆瓣)
Description: 新世界电影简介和剧情介绍,新世界影评、图片、预告片、影讯、论坛、在线购票
Keywords: 新世界,신세계,新世界影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.145豆瓣电影Top250

# 新世界 신세계 (2013)

导演: 朴勋政
编剧: 朴勋政
主演: 李政宰 / 崔岷植 / 黄政民 / 宋智孝 / 朴成雄 / 金秉玉 / 金胤成
类型: 剧情 / 犯罪
官方网站: sinsegae2013.co.kr
制片国家/地区: 韩国
语言: 韩语 / 汉语普通话
上映日期: 2013-02-21(韩国)
片长: 134分钟
又名: 暗黑新世界(台) / New World / Sinsegye
IMDb: tt2625030
豆瓣评分
引用
8.9
394535人评价
5星
54.2%
4星
37.5%
3星
7.6%
2星
0.5%
1星
0.2%
好于 98% 犯罪片
好于 98% 剧情片
想看 看过
评价:
推荐

## 新世界的剧情简介 · · · · · ·

金门集团会长、暴力组织在虎派大佬石东出遭遇车祸身亡，该事件在黑白两道引起不小震荡。为了遏制金门集团进一步向合法领域渗透并持续壮大，警方及时提出“新世界计划”，旨在干预金门集团继任大佬的选举。而围绕会长头衔，金门旗下三号人物华侨出身的丁青（黄正民 饰）和四号人物常务理事李仲久（朴圣雄 饰）展开一连串明争暗斗。在危机四伏的当下，警方姜科长（崔岷植 饰）命令卧底十年之久的李子成（李政宰 饰）左右选举结果。子成六年前和丁青结识，并且得到对方的器重和信任。早已厌倦黑道生活的子成无奈受命，却无疑将自己投入了凶险非常的黑色漩涡之中。
充满鲜血与欲望的战场，新世界何日来临？ ©豆瓣

## 新世界的演职员 · · · · · · ( 全部 35 )

- 朴勋政 导演
- 李政宰 饰 李子成
- 崔岷植 饰 姜科长
- 黄政民 饰 丁青
- 宋智孝 演员
- 朴成雄 饰 李仲久

## 新世界的视频和图片 · · · · · · ( 预告片4 | 添加视频评论 | 图片1259 · 添加 )

## 新世界的获奖情况 · · · · · · ( 全部 )

- 第34届韩国电影青龙奖
- 最佳影片(提名)

- 第49届百想艺术大赏
- 电影类 最佳男主角(提名)
- 黄政民

- 第50届韩国电影大钟奖
- 最佳影片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  卑劣的街头

  猫鼠游戏

  黄海

  与犯罪的战争：坏家伙的全盛时代

  无间道2

  教父2

  局内人

  黑社会

  上帝之城

  英雄本色

我要写短评

## 新世界的短评 · · · · · · ( 全部 94773 条 )

热门 / 最新 / 好友

### 9959 有用 猪able 看过 2013-04-02 16:43:04

好伟大的爱情片，我都快哭了

### 7070 有用 wallace李 看过 2017-05-27 18:09:49

弄巧成拙姜科长，无心插柳李子成，唯我独尊李仲久，超长待机是丁青，壮哉天朝大黑客，实力助攻小延边，智商不够高局长，我没看够宋智孝

### 3544 有用 恶魔奶爸Sam 看过 2016-07-06 22:05:01

最后还是华侨统一了南棒黑社会，中国人最狠啊。。。

### 1586 有用 张小北 看过 2013-06-02 19:05:50

韩国电影的山寨路线中心思想就是【西巴！】——要做就做狠一点，于是，新鲜的东西就出现了。

### 4312 有用 木卫二 看过 2013-05-20 02:33:53

哈哈，延边刀客，中国黑客

> 更多短评 94773条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 新世界的影评 · · · · · · ( 全部 1039 条 )

热门 / 最新 / 好友
了不起的花轮君 2013-05-10 19:37:04

## 卧底卧到这份上，才叫熬出头了

这篇影评可能有剧透

原谅我用这么三俗的标题，但是本来冲着罪案，黑道、卧底题材来的我，再次被真爱感动。 刚出场的时候，黑道集团老大意外过世，几个继承人开始王位之争。丁青那真是地痞得不能更痞，所有人都对他毕恭毕敬，身为他的左膀右臂的辅佐——李子成一副爱理不理的表情，... (展开)
5918 508 653回应 收起
恺子哥 2013-05-11 10:05:25

## 洞察人性，《新世界》远胜《无间道》

这篇影评可能有剧透

韩国电影《新世界》，几乎是近十年来最优秀的黑帮电影，不是之一，从剧情设计、剪辑和音乐等方面，其他电影很难与之匹敌。国内为之震撼的《无间道》相比之下差的很远。 对于同一类型题材的电影，通常我们先看到的，会给予较高评价，而对后面的审美情趣就要求高一些。《新世界》... (展开)
5411 1506 1648回应 收起
木卫二 2013-06-01 12:28:10

## 一个字头的诞生

很显然，《新世界》会被认为是《无间道》卧底题材的延续，同时还要被拿来与《无间道风云》等一系列片子作比较。影片重提了命悬一线的卧底命运，又用帮派内部的争抢字头来深化这种类型片特定人物的身份悲剧。 香港《无间道》精致，西装笔挺，浪漫且抒情。《无间道风云》粗粝，街... (展开)
926 132 99回应 收起
lohengramm710 2016-07-23 01:49:53

## 新世界-李子成和丁青

这篇影评可能有剧透

本来并不喜欢看韩国电影，最近一连看了《新世界》整整3遍，完全被李政宰扮演的李子成圈粉了。从电影中几个细节谈谈自己对李子成和丁青的看法： 1、从丁青穿着飞机拖鞋出场开始，就一直嬉皮笑脸、痞气十足，甚至有点二逼地和手下打闹。而一直表情严肃的李子成对丁青态... (展开)
601 3 65回应 收起
南方朋克 2013-05-08 18:36:34

## 中国山寨劳力士立功了

这篇影评可能有剧透

如果你是个卧底，你担惊受怕的忍受了八年，而你的上司对你却没有一句好话。而你上面的黑帮老大见到你一口一个兄弟，出去时时不忘给你带礼物。而你的警察上司呢，给了你承诺，但承诺却迟迟不兑现。在需要你的时候给你买点东西。在为了盲目的正义时不顾情义。 姜科长没有把李子... (展开)
472 123 125回应 收起
何求美人折 2013-05-08 22:34:05

## 卧底的逆袭

不得不说这是今年看过的最好的最喜欢的韩片。没有之一。 前几天看《七号房的礼物》的确哭得稀里哗啦。但温情范，特别是韩片，或多或少都带些催泪的矫情。感动之余，还少些快意。一直觉得一些纯动作片，虽场面火爆，但总觉“胸大无脑”。好故事，好电影，真实精彩火爆之余，总... (展开)
409 51 105回应 收起
多喝热水 2015-10-04 15:50:26

## 心要狠一点儿，才能活下去

这篇影评可能有剧透

这应该是我看过的最暴力的韩国电影。 黑暗、血腥，充斥着满满的危险气息，从头到尾、每个节奏都是无处不在的压迫感。 每个人物都宛若置身于角斗场，小心行事，狠毒捅刀。 一方面敛住自己的气息，提防着潜伏在黑暗处窥伺着自己的野兽；一方面打磨着尖刻的爪子和牙齿，... (展开)
197 14 26回应 收起
娃娃鱼 2013-07-31 15:46:37 #《新世界》有哪些有趣的设定？

## 《新世界》：在黑暗中诞生

兄弟 很多年前，在学校旁边的录像厅里，看吴宇森的《喋血双雄》。那会儿，还不知道VCD为何物，是录像带的天下；电影里也不流行搞基，满眼都是小庄和李sir的兄弟情；那时候，叶倩文既没有嫁给林子祥，也没有上春晚，一派玉女模样，清纯可人。 屏幕上，小虾和毛球端着枪，背靠背... (展开)
209 3 38回应 收起
大隐者深度影评 2020-04-15 09:39:35

## 这可能是你读到的关于电影《新世界》最全面的解读

这篇影评可能有剧透

如果以成年人的角度来解析电影《新世界》 此篇为本人创作，如有转载需注明！ 我喜欢把好电影的解读联系实际，这样才不枉费看电影花的时间。看了几篇高赞的影评，对情节的描述很详细，但有个共性问题，就是心里怀着小美好来分析这部电影，比如丁青重情重义、姜科长冷血之类的，... (展开)
275 2 35回应 收起
白胖饺子 2013-05-19 14:57:47

## 情义与现实的两难境地

当丁青拿着李子成的档案默默端详的时候，就知道其实这并不是一部犯罪或者黑帮片了。也知道了为什么这部所谓的卧底片为什么并没有卧底的斗智戏，甚至连主线的正邪斗争都做的松松散散，而不见有力的剧情冲突。 这其实是一部关于情义和生存的电影，重点表现的是情义和现实的两难... (展开)
177 20 53回应 收起

> 更多影评 1039篇

添加新讨论

## 讨论区 · · · · · ·

新世界到底抄袭了多少电影 | 来自无有财 | 25 回应 | 2022-11-24 19:00:41
有个问题 张守基为什么会说有李子成在的话无论对谁... | 来自名可君听斯基 | 4 回应 | 2022-11-24 16:36:24
这个电影我看了无数遍 每一遍看都感觉警方是最无耻... | 来自回眸一笑百媚生 | 5 回应 | 2022-11-24 15:23:27
关于李子成妻子 | 来自火云邪神 | 7 回应 | 2022-11-24 00:05:30
李子成老婆知道他是警察卧底吗？ | 来自斌枫记忆 | 9 回应 | 2022-11-23 22:19:29

> 去这部影片的讨论区（全部463条）

## 关于《新世界》的问题 · · · · · · ( 全部75个 )

- 影片最后那个6年前的回忆代表了什么 ？表示没看懂？ 27人回答
- 大家有没有觉得老姜最后在鱼池被杀太弱了？ 28人回答

> 全部75个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 2013 豆瓣电影【口碑榜】 (影志)
- 【容易忽视的好电影】 (影志)
- 木卫清单｜你不应该错过的100部韩国电影 (木卫二)
- 2013新电影（这些，可以期待） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- whcwhcwhc
  1分钟前 想看
- Cloris雷菁
  4分钟前 看过
- 豆友O4WfE_FJiI
  7分钟前 看过

503751人看过 / 191337人想看

订阅新世界的评论:
feed: rss 2.0